# Mulguisin

The Mulguisin is a cluster/group finding algorithm in galaxy data. 
It can find cluster/group structure from the galaxy data and also provide topological informations.

It has been developed by InKyu Park to find jet structure for the LHC experiment.
Now, he modify the Mulguisin that can be applied to galaxy data.
